log

package
v0.0.0-...-3e88d7f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2024 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	RED   = "\033[31m"
	RESET = "\033[0m"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger struct{}

func New

func New() *Logger

New used for generate new logger instance of Logger struct

func (*Logger) Error

func (lg *Logger) Error(err error)

Error

func (*Logger) Fatal

func (lg *Logger) Fatal(err error)

Fatal will show an error and exit with not success status code

func (*Logger) Info

func (lg *Logger) Info(err error)

Info will show information messages in stdout

func (*Logger) Warning

func (lg *Logger) Warning(err error)

Warning

Jump to